==> kibana-7.17.3-linux-x86_64.tar.gz: kibana-7.17.3-linux-x86_64/src/core/server/saved_objects/migrationsv2/actions/check_for_unknown_docs.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkForUnknownDocs = void 0;

var Either = _interopRequireWildcard(require("fp-ts/lib/Either"));

var _catch_retryable_es_client_errors = require("./catch_retryable_es_client_errors");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
const checkForUnknownDocs = ({
  client,
  indexName,
  unusedTypesQuery,
  knownTypes
}) => () => {
  const query = createUnknownDocQuery(unusedTypesQuery, knownTypes);
  return client.search({
    index: indexName,
    body: {
      query
    }
  }).then(response => {
    const {
      hits
    } = response.body.hits;
    return Either.right({
      unknownDocs: hits.map(hit => {
        var _hit$_source$type, _hit$_source;

        return {
          id: hit._id,
          type: (_hit$_source$type = (_hit$_source = hit._source) === null || _hit$_source === void 0 ? void 0 : _hit$_source.type) !== null && _hit$_source$type !== void 0 ? _hit$_source$type : 'unknown'
        };
      })
    });
  }).catch(_catch_retryable_es_client_errors.catchRetryableEsClientErrors);
};

exports.checkForUnknownDocs = checkForUnknownDocs;

const createUnknownDocQuery = (unusedTypesQuery, knownTypes) => {
  return {
    bool: {
      must: unusedTypesQuery,
      must_not: knownTypes.map(type => ({
        term: {
          type
        }
      }))
    }
  };
};

==> kibana-7.17.25-linux-x86_64.tar.gz: kibana-7.17.25-linux-x86_64/src/core/server/saved_objects/migrationsv2/actions/check_for_unknown_docs.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkForUnknownDocs = void 0;
var Either = _interopRequireWildcard(require("fp-ts/lib/Either"));
var _catch_retryable_es_client_errors = require("./catch_retryable_es_client_errors");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

/** @internal */

/** @internal */

/** @internal */

const checkForUnknownDocs = ({
  client,
  indexName,
  unusedTypesQuery,
  knownTypes
}) => () => {
  const query = createUnknownDocQuery(unusedTypesQuery, knownTypes);
  return client.search({
    index: indexName,
    body: {
      query
    }
  }).then(response => {
    const {
      hits
    } = response.body.hits;
    return Either.right({
      unknownDocs: hits.map(hit => {
        var _hit$_source$type, _hit$_source;
        return {
          id: hit._id,
          type: (_hit$_source$type = (_hit$_source = hit._source) === null || _hit$_source === void 0 ? void 0 : _hit$_source.type) !== null && _hit$_source$type !== void 0 ? _hit$_source$type : 'unknown'
        };
      })
    });
  }).catch(_catch_retryable_es_client_errors.catchRetryableEsClientErrors);
};
exports.checkForUnknownDocs = checkForUnknownDocs;
const createUnknownDocQuery = (unusedTypesQuery, knownTypes) => {
  return {
    bool: {
      must: unusedTypesQuery,
      must_not: knownTypes.map(type => ({
        term: {
          type
        }
      }))
    }
  };
};
